@@ -1120,11 +1120,6 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
 		EMPTY_IF_NULL(opt_and_args[1]), 
 		entry));
 
-  xnee_verbose((xd, "\tlong option: '%u'\n", 
-		(unsigned int) xnee_options[entry].option));
-  xnee_verbose((xd, "\tshort option:'%u'\n", 
-		(unsigned int) xnee_options[entry].short_option));
-
   xnee_verbose((xd, "\tlong option: '%s'\n", 
 		EMPTY_IF_NULL(xnee_options[entry].option)));
   xnee_verbose((xd, "\tshort option:'%s'\n", 
