@@ -1,3 +1,28 @@
+/*****
+ *       Xnee's Not an Event Emulator                                
+ *                                                                   
+ * Xnee enables recording and replaying of X protocol data           
+ *                                                                   
+ *   Copyright (C) 2006, 2007, 2010
+ *                        Henrik Sandklef 
+ *                                                                   
+ * This program is free software; you can redistribute it and/or     
+ * modify it under the terms of the GNU General Public License       
+ * as published by the Free Software Foundation; either version 3    
+ * of the License, or any later version.                             
+ *                                                                   
+ *                                                                   
+ * This program is distributed in the hope that it will be useful,   
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of    
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
+ * GNU General Public License for more details.                      
+ *                                                                   
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software       
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
+ ****/
+
 #include "test_setget.h"
 #include "libxnee/xnee.h"
 
@@ -41,7 +66,7 @@ test_distributionfuns(xnee_data *xd)
   XNEE_TEST_ASSERT(ret, 0, "xnee_print_distr_list");
   
   
-
+  return 0;
 }
 
 int 
@@ -90,7 +115,7 @@ test_rangefuns(xnee_data *xd)
   ret = xnee_print_data_str(xd, "MotionNotify", XNEE_EVENT);
   XNEE_TEST_ASSERT(ret, 0, "xnee_print_data_str");
 
-
+  return 0;
 }
 
 int 
@@ -223,6 +248,7 @@ test_printfuns(xnee_data *xd)
   xnee_record_print_error (xd, xrecintd );
   total++;
 
+  return 0;
 }
 
 int main()
@@ -254,15 +280,13 @@ int main()
   xnee_unset_verbose(xdl);
 
   fprintf (stdout, "\n");
-  fprintf (stdout, "\tSucesss:  %d\n", total);
-  fprintf (stdout, "\tFailures: %d\n", fails);
+  fprintf (stdout, "\tSucesses:  %d\n", total);
+  fprintf (stdout, "\tFailures:  %d\n", fails);
 
   xnee_close_down(xdl);
 
   
       
   return 0;
-
-
 }
 
